@@ -24,13 +24,16 @@ test_that("Includes work", {
   expect_match(val$body, ".*<html.*</html>\\s*$")
   expect_equal(val$headers$`Content-type`, "text/html; charset=utf-8")
 
-  res <- PlumberResponse$new()
-  val <- r$route(make_req("GET", "/md"), res)
-  expect_match(val$body, "<html.*<h2>R Output</h2>.*</html>\\s*$")
-  expect_equal(val$headers$`Content-type`, "text/html; charset=utf-8")
+  # Skip these tests on some CRAN instances
+  if (rmarkdown::pandoc_available()){
+    res <- PlumberResponse$new()
+    val <- r$route(make_req("GET", "/md"), res)
+    expect_match(val$body, "<html.*<h2>R Output</h2>.*</html>\\s*$")
+    expect_equal(val$headers$`Content-type`, "text/html; charset=utf-8")
 
-  res <- PlumberResponse$new()
-  val <- r$route(make_req("GET", "/rmd"), res)
-  expect_match(val$body, "<html.*<img src=\"data:image/png;base64.*</html>\\s*$")
-  expect_equal(val$headers$`Content-type`, "text/html; charset=utf-8")
+    res <- PlumberResponse$new()
+    val <- r$route(make_req("GET", "/rmd"), res)
+    expect_match(val$body, "<html.*<img src=\"data:image/png;base64.*</html>\\s*$")
+    expect_equal(val$headers$`Content-type`, "text/html; charset=utf-8")
+  }
 })
